Class: Google::Cloud::Video::Transcoder::V1::Encryption

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/video/transcoder/v1/resources.rb

Overview

Encryption settings.

Defined Under Namespace

Classes: Aes128Encryption, Clearkey, DrmSystems, Fairplay, MpegCommonEncryption, Playready, SampleAesEncryption, SecretManagerSource, Widevine

Instance Attribute Summary collapse

Instance Attribute Details

#aes_128::Google::Cloud::Video::Transcoder::V1::Encryption::Aes128Encryption

Returns Configuration for AES-128 encryption.

Note: The following fields are mutually exclusive: aes_128, sample_aes, mpeg_cenc. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1673

class Encryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for AES-128 encryption.
  class Aes128Encryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for SAMPLE-AES encryption.
  class SampleAesEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for MPEG Common Encryption (MPEG-CENC).
  # @!attribute [rw] scheme
  #   @return [::String]
  #     Required. Specify the encryption scheme.
  #
  #     Supported encryption schemes:
  #
  #     - `cenc`
  #     - `cbcs`
  class MpegCommonEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for secrets stored in Google Secret Manager.
  # @!attribute [rw] secret_version
  #   @return [::String]
  #     Required. The name of the Secret Version containing the encryption key in
  #     the following format:
  #     `projects/{project}/secrets/{secret_id}/versions/{version_number}`
  #
  #     Note that only numbered versions are supported. Aliases like "latest" are
  #     not supported.
  class SecretManagerSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Widevine configuration.
  class Widevine
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Fairplay configuration.
  class Fairplay
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Playready configuration.
  class Playready
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Clearkey configuration.
  class Clearkey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines configuration for DRM systems in use.
  # @!attribute [rw] widevine
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Widevine]
  #     Widevine configuration.
  # @!attribute [rw] fairplay
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Fairplay]
  #     Fairplay configuration.
  # @!attribute [rw] playready
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Playready]
  #     Playready configuration.
  # @!attribute [rw] clearkey
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Clearkey]
  #     Clearkey configuration.
  class DrmSystems
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#drm_systems::Google::Cloud::Video::Transcoder::V1::Encryption::DrmSystems

Returns Required. DRM system(s) to use; at least one must be specified. If a DRM system is omitted, it is considered disabled.

Returns:



1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1673

class Encryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for AES-128 encryption.
  class Aes128Encryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for SAMPLE-AES encryption.
  class SampleAesEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for MPEG Common Encryption (MPEG-CENC).
  # @!attribute [rw] scheme
  #   @return [::String]
  #     Required. Specify the encryption scheme.
  #
  #     Supported encryption schemes:
  #
  #     - `cenc`
  #     - `cbcs`
  class MpegCommonEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for secrets stored in Google Secret Manager.
  # @!attribute [rw] secret_version
  #   @return [::String]
  #     Required. The name of the Secret Version containing the encryption key in
  #     the following format:
  #     `projects/{project}/secrets/{secret_id}/versions/{version_number}`
  #
  #     Note that only numbered versions are supported. Aliases like "latest" are
  #     not supported.
  class SecretManagerSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Widevine configuration.
  class Widevine
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Fairplay configuration.
  class Fairplay
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Playready configuration.
  class Playready
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Clearkey configuration.
  class Clearkey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines configuration for DRM systems in use.
  # @!attribute [rw] widevine
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Widevine]
  #     Widevine configuration.
  # @!attribute [rw] fairplay
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Fairplay]
  #     Fairplay configuration.
  # @!attribute [rw] playready
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Playready]
  #     Playready configuration.
  # @!attribute [rw] clearkey
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Clearkey]
  #     Clearkey configuration.
  class DrmSystems
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id::String

Returns Required. Identifier for this set of encryption options.

Returns:

  • (::String)

    Required. Identifier for this set of encryption options.



1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1673

class Encryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for AES-128 encryption.
  class Aes128Encryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for SAMPLE-AES encryption.
  class SampleAesEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for MPEG Common Encryption (MPEG-CENC).
  # @!attribute [rw] scheme
  #   @return [::String]
  #     Required. Specify the encryption scheme.
  #
  #     Supported encryption schemes:
  #
  #     - `cenc`
  #     - `cbcs`
  class MpegCommonEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for secrets stored in Google Secret Manager.
  # @!attribute [rw] secret_version
  #   @return [::String]
  #     Required. The name of the Secret Version containing the encryption key in
  #     the following format:
  #     `projects/{project}/secrets/{secret_id}/versions/{version_number}`
  #
  #     Note that only numbered versions are supported. Aliases like "latest" are
  #     not supported.
  class SecretManagerSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Widevine configuration.
  class Widevine
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Fairplay configuration.
  class Fairplay
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Playready configuration.
  class Playready
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Clearkey configuration.
  class Clearkey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines configuration for DRM systems in use.
  # @!attribute [rw] widevine
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Widevine]
  #     Widevine configuration.
  # @!attribute [rw] fairplay
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Fairplay]
  #     Fairplay configuration.
  # @!attribute [rw] playready
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Playready]
  #     Playready configuration.
  # @!attribute [rw] clearkey
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Clearkey]
  #     Clearkey configuration.
  class DrmSystems
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#mpeg_cenc::Google::Cloud::Video::Transcoder::V1::Encryption::MpegCommonEncryption

Returns Configuration for MPEG Common Encryption (MPEG-CENC).

Note: The following fields are mutually exclusive: mpeg_cenc, aes_128, sample_aes. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1673

class Encryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for AES-128 encryption.
  class Aes128Encryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for SAMPLE-AES encryption.
  class SampleAesEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for MPEG Common Encryption (MPEG-CENC).
  # @!attribute [rw] scheme
  #   @return [::String]
  #     Required. Specify the encryption scheme.
  #
  #     Supported encryption schemes:
  #
  #     - `cenc`
  #     - `cbcs`
  class MpegCommonEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for secrets stored in Google Secret Manager.
  # @!attribute [rw] secret_version
  #   @return [::String]
  #     Required. The name of the Secret Version containing the encryption key in
  #     the following format:
  #     `projects/{project}/secrets/{secret_id}/versions/{version_number}`
  #
  #     Note that only numbered versions are supported. Aliases like "latest" are
  #     not supported.
  class SecretManagerSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Widevine configuration.
  class Widevine
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Fairplay configuration.
  class Fairplay
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Playready configuration.
  class Playready
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Clearkey configuration.
  class Clearkey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines configuration for DRM systems in use.
  # @!attribute [rw] widevine
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Widevine]
  #     Widevine configuration.
  # @!attribute [rw] fairplay
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Fairplay]
  #     Fairplay configuration.
  # @!attribute [rw] playready
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Playready]
  #     Playready configuration.
  # @!attribute [rw] clearkey
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Clearkey]
  #     Clearkey configuration.
  class DrmSystems
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#sample_aes::Google::Cloud::Video::Transcoder::V1::Encryption::SampleAesEncryption

Returns Configuration for SAMPLE-AES encryption.

Note: The following fields are mutually exclusive: sample_aes, aes_128, mpeg_cenc. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1673

class Encryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for AES-128 encryption.
  class Aes128Encryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for SAMPLE-AES encryption.
  class SampleAesEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for MPEG Common Encryption (MPEG-CENC).
  # @!attribute [rw] scheme
  #   @return [::String]
  #     Required. Specify the encryption scheme.
  #
  #     Supported encryption schemes:
  #
  #     - `cenc`
  #     - `cbcs`
  class MpegCommonEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for secrets stored in Google Secret Manager.
  # @!attribute [rw] secret_version
  #   @return [::String]
  #     Required. The name of the Secret Version containing the encryption key in
  #     the following format:
  #     `projects/{project}/secrets/{secret_id}/versions/{version_number}`
  #
  #     Note that only numbered versions are supported. Aliases like "latest" are
  #     not supported.
  class SecretManagerSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Widevine configuration.
  class Widevine
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Fairplay configuration.
  class Fairplay
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Playready configuration.
  class Playready
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Clearkey configuration.
  class Clearkey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines configuration for DRM systems in use.
  # @!attribute [rw] widevine
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Widevine]
  #     Widevine configuration.
  # @!attribute [rw] fairplay
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Fairplay]
  #     Fairplay configuration.
  # @!attribute [rw] playready
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Playready]
  #     Playready configuration.
  # @!attribute [rw] clearkey
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Clearkey]
  #     Clearkey configuration.
  class DrmSystems
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#secret_manager_key_source::Google::Cloud::Video::Transcoder::V1::Encryption::SecretManagerSource

Returns Keys are stored in Google Secret Manager.

Returns:



1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1673

class Encryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for AES-128 encryption.
  class Aes128Encryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for SAMPLE-AES encryption.
  class SampleAesEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for MPEG Common Encryption (MPEG-CENC).
  # @!attribute [rw] scheme
  #   @return [::String]
  #     Required. Specify the encryption scheme.
  #
  #     Supported encryption schemes:
  #
  #     - `cenc`
  #     - `cbcs`
  class MpegCommonEncryption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration for secrets stored in Google Secret Manager.
  # @!attribute [rw] secret_version
  #   @return [::String]
  #     Required. The name of the Secret Version containing the encryption key in
  #     the following format:
  #     `projects/{project}/secrets/{secret_id}/versions/{version_number}`
  #
  #     Note that only numbered versions are supported. Aliases like "latest" are
  #     not supported.
  class SecretManagerSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Widevine configuration.
  class Widevine
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Fairplay configuration.
  class Fairplay
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Playready configuration.
  class Playready
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Clearkey configuration.
  class Clearkey
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines configuration for DRM systems in use.
  # @!attribute [rw] widevine
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Widevine]
  #     Widevine configuration.
  # @!attribute [rw] fairplay
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Fairplay]
  #     Fairplay configuration.
  # @!attribute [rw] playready
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Playready]
  #     Playready configuration.
  # @!attribute [rw] clearkey
  #   @return [::Google::Cloud::Video::Transcoder::V1::Encryption::Clearkey]
  #     Clearkey configuration.
  class DrmSystems
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end