Class: Google::Cloud::Video::Transcoder::V1::InputAttributes

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/video/transcoder/v1/resources.rb

Overview

Input attributes that provide additional information about the input asset.

Instance Attribute Summary collapse

Instance Attribute Details

#track_definitions::Array<::Google::Cloud::Video::Transcoder::V1::TrackDefinition>

Returns Optional. A list of track definitions for the input asset.

Returns:



960
961
962
963
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 960

class InputAttributes
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end