Module: Google::Cloud::Video::Transcoder::V1::Manifest::DashConfig::SegmentReferenceScheme

Defined in:
proto_docs/google/cloud/video/transcoder/v1/resources.rb

Overview

The segment reference scheme for a DASH manifest.

Constant Summary collapse

SEGMENT_REFERENCE_SCHEME_UNSPECIFIED =

The segment reference scheme is not specified.

0
SEGMENT_LIST =

Explicitly lists the URLs of media files for each segment. For example, if SegmentSettings.individual_segments is true, then the manifest contains fields similar to the following:

<Initialization sourceURL="my-hd-stream-init.m4s"/>
  <SegmentList presentationTimeOffset="0" duration="1000"
  timescale="10000">
    <SegmentURL media="hd-stream0000000000.m4s"/>
    <SegmentURL media="hd-stream0000000001.m4s"/>
    ...
1
SEGMENT_TEMPLATE_NUMBER =

SegmentSettings.individual_segments must be set to true to use this segment reference scheme. Uses the DASH specification <SegmentTemplate> tag to determine the URLs of media files for each segment. For example:

<SegmentTemplate presentationTimeOffset="0" timescale="10000"
      initialization="my-hd-stream-init.m4s"
      media="hd-stream$Number%010d$.m4s" startNumber="0">
  ...
2