Class: Google::Cloud::Video::Transcoder::V1::Overlay
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::Overlay
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
Overlay configuration.
Defined Under Namespace
Modules: FadeType Classes: Animation, AnimationEnd, AnimationFade, AnimationStatic, Image, NormalizedCoordinate
Instance Attribute Summary collapse
-
#animations ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1::Overlay::Animation>
List of animations.
-
#image ⇒ ::Google::Cloud::Video::Transcoder::V1::Overlay::Image
Image overlay.
Instance Attribute Details
#animations ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1::Overlay::Animation>
Returns List of animations. The list should be chronological, without any time overlap.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 583 class Overlay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # 2D normalized coordinates. Default: `{0.0, 0.0}` # @!attribute [rw] x # @return [::Float] # Normalized x coordinate. # @!attribute [rw] y # @return [::Float] # Normalized y coordinate. class NormalizedCoordinate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overlaid image. # @!attribute [rw] uri # @return [::String] # Required. URI of the image in Cloud Storage. For example, # `gs://bucket/inputs/image.png`. Only PNG and JPEG images are supported. # @!attribute [rw] resolution # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::NormalizedCoordinate] # Normalized image resolution, based on output video resolution. Valid # values: `0.0`–`1.0`. To respect the original image aspect ratio, set # either `x` or `y` to `0.0`. To use the original image resolution, set # both `x` and `y` to `0.0`. # @!attribute [rw] alpha # @return [::Float] # Target image opacity. Valid values are from `1.0` (solid, default) to # `0.0` (transparent), exclusive. Set this to a value greater than `0.0`. class Image include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Display static overlay object. # @!attribute [rw] xy # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::NormalizedCoordinate] # Normalized coordinates based on output video resolution. Valid # values: `0.0`–`1.0`. `xy` is the upper-left coordinate of the overlay # object. For example, use the x and y coordinates \\{0,0} to position the # top-left corner of the overlay animation in the top-left corner of the # output video. # @!attribute [rw] start_time_offset # @return [::Google::Protobuf::Duration] # The time to start displaying the overlay object, in seconds. Default: 0 class AnimationStatic include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Display overlay object with fade animation. # @!attribute [rw] fade_type # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::FadeType] # Required. Type of fade animation: `FADE_IN` or `FADE_OUT`. # @!attribute [rw] xy # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::NormalizedCoordinate] # Normalized coordinates based on output video resolution. Valid # values: `0.0`–`1.0`. `xy` is the upper-left coordinate of the overlay # object. For example, use the x and y coordinates \\{0,0} to position the # top-left corner of the overlay animation in the top-left corner of the # output video. # @!attribute [rw] start_time_offset # @return [::Google::Protobuf::Duration] # The time to start the fade animation, in seconds. Default: 0 # @!attribute [rw] end_time_offset # @return [::Google::Protobuf::Duration] # The time to end the fade animation, in seconds. Default: # `start_time_offset` + 1s class AnimationFade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # End previous overlay animation from the video. Without `AnimationEnd`, the # overlay object will keep the state of previous animation until the end of # the video. # @!attribute [rw] start_time_offset # @return [::Google::Protobuf::Duration] # The time to end overlay object, in seconds. Default: 0 class AnimationEnd include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Animation types. # @!attribute [rw] animation_static # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::AnimationStatic] # Display static overlay object. # # Note: The following fields are mutually exclusive: `animation_static`, `animation_fade`, `animation_end`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] animation_fade # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::AnimationFade] # Display overlay object with fade animation. # # Note: The following fields are mutually exclusive: `animation_fade`, `animation_static`, `animation_end`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] animation_end # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::AnimationEnd] # End previous animation. # # Note: The following fields are mutually exclusive: `animation_end`, `animation_static`, `animation_fade`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Animation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Fade type for the overlay: `FADE_IN` or `FADE_OUT`. module FadeType # The fade type is not specified. FADE_TYPE_UNSPECIFIED = 0 # Fade the overlay object into view. FADE_IN = 1 # Fade the overlay object out of view. FADE_OUT = 2 end end |
#image ⇒ ::Google::Cloud::Video::Transcoder::V1::Overlay::Image
Returns Image overlay.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 583 class Overlay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # 2D normalized coordinates. Default: `{0.0, 0.0}` # @!attribute [rw] x # @return [::Float] # Normalized x coordinate. # @!attribute [rw] y # @return [::Float] # Normalized y coordinate. class NormalizedCoordinate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overlaid image. # @!attribute [rw] uri # @return [::String] # Required. URI of the image in Cloud Storage. For example, # `gs://bucket/inputs/image.png`. Only PNG and JPEG images are supported. # @!attribute [rw] resolution # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::NormalizedCoordinate] # Normalized image resolution, based on output video resolution. Valid # values: `0.0`–`1.0`. To respect the original image aspect ratio, set # either `x` or `y` to `0.0`. To use the original image resolution, set # both `x` and `y` to `0.0`. # @!attribute [rw] alpha # @return [::Float] # Target image opacity. Valid values are from `1.0` (solid, default) to # `0.0` (transparent), exclusive. Set this to a value greater than `0.0`. class Image include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Display static overlay object. # @!attribute [rw] xy # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::NormalizedCoordinate] # Normalized coordinates based on output video resolution. Valid # values: `0.0`–`1.0`. `xy` is the upper-left coordinate of the overlay # object. For example, use the x and y coordinates \\{0,0} to position the # top-left corner of the overlay animation in the top-left corner of the # output video. # @!attribute [rw] start_time_offset # @return [::Google::Protobuf::Duration] # The time to start displaying the overlay object, in seconds. Default: 0 class AnimationStatic include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Display overlay object with fade animation. # @!attribute [rw] fade_type # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::FadeType] # Required. Type of fade animation: `FADE_IN` or `FADE_OUT`. # @!attribute [rw] xy # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::NormalizedCoordinate] # Normalized coordinates based on output video resolution. Valid # values: `0.0`–`1.0`. `xy` is the upper-left coordinate of the overlay # object. For example, use the x and y coordinates \\{0,0} to position the # top-left corner of the overlay animation in the top-left corner of the # output video. # @!attribute [rw] start_time_offset # @return [::Google::Protobuf::Duration] # The time to start the fade animation, in seconds. Default: 0 # @!attribute [rw] end_time_offset # @return [::Google::Protobuf::Duration] # The time to end the fade animation, in seconds. Default: # `start_time_offset` + 1s class AnimationFade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # End previous overlay animation from the video. Without `AnimationEnd`, the # overlay object will keep the state of previous animation until the end of # the video. # @!attribute [rw] start_time_offset # @return [::Google::Protobuf::Duration] # The time to end overlay object, in seconds. Default: 0 class AnimationEnd include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Animation types. # @!attribute [rw] animation_static # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::AnimationStatic] # Display static overlay object. # # Note: The following fields are mutually exclusive: `animation_static`, `animation_fade`, `animation_end`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] animation_fade # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::AnimationFade] # Display overlay object with fade animation. # # Note: The following fields are mutually exclusive: `animation_fade`, `animation_static`, `animation_end`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] animation_end # @return [::Google::Cloud::Video::Transcoder::V1::Overlay::AnimationEnd] # End previous animation. # # Note: The following fields are mutually exclusive: `animation_end`, `animation_static`, `animation_fade`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Animation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Fade type for the overlay: `FADE_IN` or `FADE_OUT`. module FadeType # The fade type is not specified. FADE_TYPE_UNSPECIFIED = 0 # Fade the overlay object into view. FADE_IN = 1 # Fade the overlay object out of view. FADE_OUT = 2 end end |