Class: Google::Cloud::Video::Transcoder::V1::Overlay::AnimationFade
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::Overlay::AnimationFade
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
Display overlay object with fade animation.
Instance Attribute Summary collapse
-
#end_time_offset ⇒ ::Google::Protobuf::Duration
The time to end the fade animation, in seconds.
-
#fade_type ⇒ ::Google::Cloud::Video::Transcoder::V1::Overlay::FadeType
Required.
-
#start_time_offset ⇒ ::Google::Protobuf::Duration
The time to start the fade animation, in seconds.
-
#xy ⇒ ::Google::Cloud::Video::Transcoder::V1::Overlay::NormalizedCoordinate
Normalized coordinates based on output video resolution.
Instance Attribute Details
#end_time_offset ⇒ ::Google::Protobuf::Duration
591 592 593 594 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 591 class AnimationFade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fade_type ⇒ ::Google::Cloud::Video::Transcoder::V1::Overlay::FadeType
591 592 593 594 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 591 class AnimationFade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time_offset ⇒ ::Google::Protobuf::Duration
591 592 593 594 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 591 class AnimationFade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#xy ⇒ ::Google::Cloud::Video::Transcoder::V1::Overlay::NormalizedCoordinate
591 592 593 594 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 591 class AnimationFade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |