Class: Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb

Overview

REST client for the TranscoderService service.

Using the Transcoder API, you can queue asynchronous jobs for transcoding media into various output formats. Output formats may include different streaming standards such as HTTP Live Streaming (HLS) and Dynamic Adaptive Streaming over HTTP (DASH). You can also customize jobs using advanced features such as Digital Rights Management (DRM), audio equalization, content concatenation, and digital ad-stitch ready content generation.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#job_path, #job_template_path, #location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new TranscoderService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the TranscoderService client.

Yield Parameters:



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 160

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @transcoder_service_stub = ::Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @transcoder_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the TranscoderService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all TranscoderService clients
::Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 70

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Video", "Transcoder", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_job.timeout = 60.0

    default_config.rpcs.list_jobs.timeout = 60.0
    default_config.rpcs.list_jobs.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_job.timeout = 60.0
    default_config.rpcs.get_job.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.delete_job.timeout = 60.0

    default_config.rpcs.create_job_template.timeout = 60.0

    default_config.rpcs.list_job_templates.timeout = 60.0
    default_config.rpcs.list_job_templates.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_job_template.timeout = 60.0
    default_config.rpcs.get_job_template.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.delete_job_template.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the TranscoderService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



130
131
132
133
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 130

def configure
  yield @config if block_given?
  @config
end

#create_job(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::Job #create_job(parent: nil, job: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::Job

Creates a job in the specified region.

Examples:

Basic example

require "google/cloud/video/transcoder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Video::Transcoder::V1::CreateJobRequest.new

# Call the create_job method.
result = client.create_job request

# The returned object is of type Google::Cloud::Video::Transcoder::V1::Job.
p result

Overloads:

  • #create_job(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::Job

    Pass arguments to create_job via a request object, either of type CreateJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Video::Transcoder::V1::CreateJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_job(parent: nil, job: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::Job

    Pass arguments to create_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent location to create and process this job. Format: projects/{project}/locations/{location}

    • job (::Google::Cloud::Video::Transcoder::V1::Job, ::Hash) (defaults to: nil)

      Required. Parameters for creating transcoding job.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 259

def create_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1::CreateJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_job..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Video::Transcoder::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @transcoder_service_stub.create_job request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#create_job_template(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::JobTemplate #create_job_template(parent: nil, job_template: nil, job_template_id: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::JobTemplate

Creates a job template in the specified region.

Examples:

Basic example

require "google/cloud/video/transcoder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Video::Transcoder::V1::CreateJobTemplateRequest.new

# Call the create_job_template method.
result = client.create_job_template request

# The returned object is of type Google::Cloud::Video::Transcoder::V1::JobTemplate.
p result

Overloads:

  • #create_job_template(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::JobTemplate

    Pass arguments to create_job_template via a request object, either of type CreateJobTemplateRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Video::Transcoder::V1::CreateJobTemplateRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_job_template(parent: nil, job_template: nil, job_template_id: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::JobTemplate

    Pass arguments to create_job_template via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent location to create this job template. Format: projects/{project}/locations/{location}

    • job_template (::Google::Cloud::Video::Transcoder::V1::JobTemplate, ::Hash) (defaults to: nil)

      Required. Parameters for creating job template.

    • job_template_id (::String) (defaults to: nil)

      Required. The ID to use for the job template, which will become the final component of the job template's resource name.

      This value should be 4-63 characters, and valid characters must match the regular expression [a-zA-Z][a-zA-Z0-9_-]*.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 602

def create_job_template request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1::CreateJobTemplateRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_job_template..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Video::Transcoder::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_job_template.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_job_template.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @transcoder_service_stub.create_job_template request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_job(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_job(name: nil, allow_missing: nil) ⇒ ::Google::Protobuf::Empty

Deletes a job.

Examples:

Basic example

require "google/cloud/video/transcoder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Video::Transcoder::V1::DeleteJobRequest.new

# Call the delete_job method.
result = client.delete_job request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_job(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_job via a request object, either of type DeleteJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Video::Transcoder::V1::DeleteJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_job(name: nil, allow_missing: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the job to delete. Format: projects/{project}/locations/{location}/jobs/{job}

    • allow_missing (::Boolean) (defaults to: nil)

      If set to true, and the job is not found, the request will succeed but no action will be taken on the server.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 515

def delete_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1::DeleteJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_job..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Video::Transcoder::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @transcoder_service_stub.delete_job request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_job_template(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_job_template(name: nil, allow_missing: nil) ⇒ ::Google::Protobuf::Empty

Deletes a job template.

Examples:

Basic example

require "google/cloud/video/transcoder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Video::Transcoder::V1::DeleteJobTemplateRequest.new

# Call the delete_job_template method.
result = client.delete_job_template request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_job_template(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_job_template via a request object, either of type DeleteJobTemplateRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Video::Transcoder::V1::DeleteJobTemplateRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_job_template(name: nil, allow_missing: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_job_template via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the job template to delete. projects/{project}/locations/{location}/jobTemplates/{job_template}

    • allow_missing (::Boolean) (defaults to: nil)

      If set to true, and the job template is not found, the request will succeed but no action will be taken on the server.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 860

def delete_job_template request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1::DeleteJobTemplateRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_job_template..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Video::Transcoder::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_job_template.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_job_template.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @transcoder_service_stub.delete_job_template request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_job(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::Job #get_job(name: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::Job

Returns the job data.

Examples:

Basic example

require "google/cloud/video/transcoder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Video::Transcoder::V1::GetJobRequest.new

# Call the get_job method.
result = client.get_job request

# The returned object is of type Google::Cloud::Video::Transcoder::V1::Job.
p result

Overloads:

  • #get_job(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::Job

    Pass arguments to get_job via a request object, either of type GetJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Video::Transcoder::V1::GetJobRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_job(name: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::Job

    Pass arguments to get_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the job to retrieve. Format: projects/{project}/locations/{location}/jobs/{job}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 433

def get_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1::GetJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_job..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Video::Transcoder::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @transcoder_service_stub.get_job request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_job_template(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::JobTemplate #get_job_template(name: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::JobTemplate

Returns the job template data.

Examples:

Basic example

require "google/cloud/video/transcoder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Video::Transcoder::V1::GetJobTemplateRequest.new

# Call the get_job_template method.
result = client.get_job_template request

# The returned object is of type Google::Cloud::Video::Transcoder::V1::JobTemplate.
p result

Overloads:

  • #get_job_template(request, options = nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::JobTemplate

    Pass arguments to get_job_template via a request object, either of type GetJobTemplateRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Video::Transcoder::V1::GetJobTemplateRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_job_template(name: nil) ⇒ ::Google::Cloud::Video::Transcoder::V1::JobTemplate

    Pass arguments to get_job_template via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the job template to retrieve. Format: projects/{project}/locations/{location}/jobTemplates/{job_template}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 778

def get_job_template request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1::GetJobTemplateRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_job_template..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Video::Transcoder::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_job_template.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_job_template.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @transcoder_service_stub.get_job_template request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_job_templates(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1::JobTemplate> #list_job_templates(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1::JobTemplate>

Lists job templates in the specified region.

Examples:

Basic example

require "google/cloud/video/transcoder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Video::Transcoder::V1::ListJobTemplatesRequest.new

# Call the list_job_templates method.
result = client.list_job_templates request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Video::Transcoder::V1::JobTemplate.
  p item
end

Overloads:

  • #list_job_templates(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1::JobTemplate>

    Pass arguments to list_job_templates via a request object, either of type ListJobTemplatesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Video::Transcoder::V1::ListJobTemplatesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_job_templates(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1::JobTemplate>

    Pass arguments to list_job_templates via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent location from which to retrieve the collection of job templates. Format: projects/{project}/locations/{location}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of items to return.

    • page_token (::String) (defaults to: nil)

      The next_page_token value returned from a previous List request, if any.

    • filter (::String) (defaults to: nil)

      The filter expression, following the syntax outlined in https://google.aip.dev/160.

    • order_by (::String) (defaults to: nil)

      One or more fields to compare and use to sort the output. See https://google.aip.dev/132#ordering.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 696

def list_job_templates request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1::ListJobTemplatesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_job_templates..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Video::Transcoder::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_job_templates.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_job_templates.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @transcoder_service_stub.list_job_templates request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @transcoder_service_stub, :list_job_templates, "job_templates", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_jobs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1::Job> #list_jobs(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1::Job>

Lists jobs in the specified region.

Examples:

Basic example

require "google/cloud/video/transcoder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Video::Transcoder::V1::TranscoderService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Video::Transcoder::V1::ListJobsRequest.new

# Call the list_jobs method.
result = client.list_jobs request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Video::Transcoder::V1::Job.
  p item
end

Overloads:

  • #list_jobs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1::Job>

    Pass arguments to list_jobs via a request object, either of type ListJobsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Video::Transcoder::V1::ListJobsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_jobs(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Video::Transcoder::V1::Job>

    Pass arguments to list_jobs via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Format: projects/{project}/locations/{location}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of items to return.

    • page_token (::String) (defaults to: nil)

      The next_page_token value returned from a previous List request, if any.

    • filter (::String) (defaults to: nil)

      The filter expression, following the syntax outlined in https://google.aip.dev/160.

    • order_by (::String) (defaults to: nil)

      One or more fields to compare and use to sort the output. See https://google.aip.dev/132#ordering.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 352

def list_jobs request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Video::Transcoder::V1::ListJobsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_jobs..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Video::Transcoder::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_jobs.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_jobs.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @transcoder_service_stub.list_jobs request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @transcoder_service_stub, :list_jobs, "jobs", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


207
208
209
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 207

def logger
  @transcoder_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


140
141
142
# File 'lib/google/cloud/video/transcoder/v1/transcoder_service/rest/client.rb', line 140

def universe_domain
  @transcoder_service_stub.universe_domain
end