Class: Google::Cloud::Video::Transcoder::V1::AudioStream
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::AudioStream
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
Audio stream resource.
Defined Under Namespace
Classes: AudioMapping
Instance Attribute Summary collapse
-
#bitrate_bps ⇒ ::Integer
Required.
-
#channel_count ⇒ ::Integer
Number of audio channels.
-
#channel_layout ⇒ ::Array<::String>
A list of channel names specifying layout of the audio channels.
-
#codec ⇒ ::String
The codec for this audio stream.
-
#display_name ⇒ ::String
The name for this particular audio stream that will be added to the HLS/DASH manifest.
-
#language_code ⇒ ::String
The BCP-47 language code, such as
en-USorsr-Latn. -
#mapping ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1::AudioStream::AudioMapping>
The mapping for the JobConfig.edit_list atoms with audio EditAtom.inputs.
-
#sample_rate_hertz ⇒ ::Integer
The audio sample rate in Hertz.
Instance Attribute Details
#bitrate_bps ⇒ ::Integer
Returns Required. Audio bitrate in bits per second. Must be between 1 and 10,000,000.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1540 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with audio # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references the atom with audio inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] input_channel # @return [::Integer] # Required. The zero-based index of the channel in the input audio stream. # @!attribute [rw] output_channel # @return [::Integer] # Required. The zero-based index of the channel in the output audio stream. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#channel_count ⇒ ::Integer
Returns Number of audio channels. Must be between 1 and 6. The default is 2.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1540 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with audio # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references the atom with audio inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] input_channel # @return [::Integer] # Required. The zero-based index of the channel in the input audio stream. # @!attribute [rw] output_channel # @return [::Integer] # Required. The zero-based index of the channel in the output audio stream. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#channel_layout ⇒ ::Array<::String>
Returns A list of channel names specifying layout of the audio channels.
This only affects the metadata embedded in the container headers, if
supported by the specified format. The default is ["fl", "fr"].
Supported channel names:
fl- Front left channelfr- Front right channelsl- Side left channelsr- Side right channelfc- Front center channellfe- Low frequency.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1540 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with audio # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references the atom with audio inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] input_channel # @return [::Integer] # Required. The zero-based index of the channel in the input audio stream. # @!attribute [rw] output_channel # @return [::Integer] # Required. The zero-based index of the channel in the output audio stream. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#codec ⇒ ::String
Returns The codec for this audio stream. The default is aac.
Supported audio codecs:
aacaac-heaac-he-v2mp3ac3eac3vorbis.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1540 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with audio # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references the atom with audio inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] input_channel # @return [::Integer] # Required. The zero-based index of the channel in the input audio stream. # @!attribute [rw] output_channel # @return [::Integer] # Required. The zero-based index of the channel in the output audio stream. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns The name for this particular audio stream that will be added to the HLS/DASH manifest. Not supported in MP4 files.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1540 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with audio # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references the atom with audio inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] input_channel # @return [::Integer] # Required. The zero-based index of the channel in the input audio stream. # @!attribute [rw] output_channel # @return [::Integer] # Required. The zero-based index of the channel in the output audio stream. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#language_code ⇒ ::String
Returns The BCP-47 language code, such as en-US or sr-Latn. For more
information, see
https://www.unicode.org/reports/tr35/#Unicode_locale_identifier. Not
supported in MP4 files.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1540 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with audio # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references the atom with audio inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] input_channel # @return [::Integer] # Required. The zero-based index of the channel in the input audio stream. # @!attribute [rw] output_channel # @return [::Integer] # Required. The zero-based index of the channel in the output audio stream. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#mapping ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1::AudioStream::AudioMapping>
Returns The mapping for the JobConfig.edit_list atoms with audio EditAtom.inputs.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1540 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with audio # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references the atom with audio inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] input_channel # @return [::Integer] # Required. The zero-based index of the channel in the input audio stream. # @!attribute [rw] output_channel # @return [::Integer] # Required. The zero-based index of the channel in the output audio stream. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sample_rate_hertz ⇒ ::Integer
Returns The audio sample rate in Hertz. The default is 48000 Hertz.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1540 class AudioStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with audio # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references the atom with audio inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. # @!attribute [rw] input_channel # @return [::Integer] # Required. The zero-based index of the channel in the input audio stream. # @!attribute [rw] output_channel # @return [::Integer] # Required. The zero-based index of the channel in the output audio stream. # @!attribute [rw] gain_db # @return [::Float] # Audio volume control in dB. Negative values decrease volume, # positive values increase. The default is 0. class AudioMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |