Class: Google::Cloud::Video::Transcoder::V1::Manifest
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::Manifest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
Manifest configuration.
Defined Under Namespace
Modules: ManifestType Classes: DashConfig
Instance Attribute Summary collapse
-
#dash ⇒ ::Google::Cloud::Video::Transcoder::V1::Manifest::DashConfig
DASHmanifest configuration. -
#file_name ⇒ ::String
The name of the generated file.
-
#mux_streams ⇒ ::Array<::String>
Required.
-
#type ⇒ ::Google::Cloud::Video::Transcoder::V1::Manifest::ManifestType
Required.
Instance Attribute Details
#dash ⇒ ::Google::Cloud::Video::Transcoder::V1::Manifest::DashConfig
Returns DASH manifest configuration.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 421 class Manifest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `DASH` manifest configuration. # @!attribute [rw] segment_reference_scheme # @return [::Google::Cloud::Video::Transcoder::V1::Manifest::DashConfig::SegmentReferenceScheme] # The segment reference scheme for a `DASH` manifest. The default is # `SEGMENT_LIST`. class DashConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The segment reference scheme for a `DASH` manifest. module SegmentReferenceScheme # The segment reference scheme is not specified. SEGMENT_REFERENCE_SCHEME_UNSPECIFIED = 0 # Explicitly lists the URLs of media files for each segment. For example, # if # {::Google::Cloud::Video::Transcoder::V1::SegmentSettings#individual_segments SegmentSettings.individual_segments} # is `true`, then the manifest contains fields similar to the following: # ```xml # <Initialization sourceURL="my-hd-stream-init.m4s"/> # <SegmentList presentationTimeOffset="0" duration="1000" # timescale="10000"> # <SegmentURL media="hd-stream0000000000.m4s"/> # <SegmentURL media="hd-stream0000000001.m4s"/> # ... # ``` SEGMENT_LIST = 1 # {::Google::Cloud::Video::Transcoder::V1::SegmentSettings#individual_segments SegmentSettings.individual_segments} # must be set to `true` to use this segment reference scheme. Uses the # DASH specification # `<SegmentTemplate>` tag to determine the URLs of media files for each # segment. For example: # ```xml # <SegmentTemplate presentationTimeOffset="0" timescale="10000" # initialization="my-hd-stream-init.m4s" # media="hd-stream$Number%010d$.m4s" startNumber="0"> # ... # ``` SEGMENT_TEMPLATE_NUMBER = 2 end end # The manifest type, which corresponds to the adaptive streaming format used. module ManifestType # The manifest type is not specified. MANIFEST_TYPE_UNSPECIFIED = 0 # Create an HLS manifest. The corresponding file extension is `.m3u8`. HLS = 1 # Create an MPEG-DASH manifest. The corresponding file extension is `.mpd`. DASH = 2 end end |
#file_name ⇒ ::String
Returns The name of the generated file. The default is manifest with the
extension suffix corresponding to the
Manifest.type.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 421 class Manifest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `DASH` manifest configuration. # @!attribute [rw] segment_reference_scheme # @return [::Google::Cloud::Video::Transcoder::V1::Manifest::DashConfig::SegmentReferenceScheme] # The segment reference scheme for a `DASH` manifest. The default is # `SEGMENT_LIST`. class DashConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The segment reference scheme for a `DASH` manifest. module SegmentReferenceScheme # The segment reference scheme is not specified. SEGMENT_REFERENCE_SCHEME_UNSPECIFIED = 0 # Explicitly lists the URLs of media files for each segment. For example, # if # {::Google::Cloud::Video::Transcoder::V1::SegmentSettings#individual_segments SegmentSettings.individual_segments} # is `true`, then the manifest contains fields similar to the following: # ```xml # <Initialization sourceURL="my-hd-stream-init.m4s"/> # <SegmentList presentationTimeOffset="0" duration="1000" # timescale="10000"> # <SegmentURL media="hd-stream0000000000.m4s"/> # <SegmentURL media="hd-stream0000000001.m4s"/> # ... # ``` SEGMENT_LIST = 1 # {::Google::Cloud::Video::Transcoder::V1::SegmentSettings#individual_segments SegmentSettings.individual_segments} # must be set to `true` to use this segment reference scheme. Uses the # DASH specification # `<SegmentTemplate>` tag to determine the URLs of media files for each # segment. For example: # ```xml # <SegmentTemplate presentationTimeOffset="0" timescale="10000" # initialization="my-hd-stream-init.m4s" # media="hd-stream$Number%010d$.m4s" startNumber="0"> # ... # ``` SEGMENT_TEMPLATE_NUMBER = 2 end end # The manifest type, which corresponds to the adaptive streaming format used. module ManifestType # The manifest type is not specified. MANIFEST_TYPE_UNSPECIFIED = 0 # Create an HLS manifest. The corresponding file extension is `.m3u8`. HLS = 1 # Create an MPEG-DASH manifest. The corresponding file extension is `.mpd`. DASH = 2 end end |
#mux_streams ⇒ ::Array<::String>
Returns Required. List of user supplied MuxStream.key values that should appear in this manifest.
When Manifest.type is
HLS, a media manifest with name
MuxStream.key and .m3u8
extension is generated for each element in this list.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 421 class Manifest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `DASH` manifest configuration. # @!attribute [rw] segment_reference_scheme # @return [::Google::Cloud::Video::Transcoder::V1::Manifest::DashConfig::SegmentReferenceScheme] # The segment reference scheme for a `DASH` manifest. The default is # `SEGMENT_LIST`. class DashConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The segment reference scheme for a `DASH` manifest. module SegmentReferenceScheme # The segment reference scheme is not specified. SEGMENT_REFERENCE_SCHEME_UNSPECIFIED = 0 # Explicitly lists the URLs of media files for each segment. For example, # if # {::Google::Cloud::Video::Transcoder::V1::SegmentSettings#individual_segments SegmentSettings.individual_segments} # is `true`, then the manifest contains fields similar to the following: # ```xml # <Initialization sourceURL="my-hd-stream-init.m4s"/> # <SegmentList presentationTimeOffset="0" duration="1000" # timescale="10000"> # <SegmentURL media="hd-stream0000000000.m4s"/> # <SegmentURL media="hd-stream0000000001.m4s"/> # ... # ``` SEGMENT_LIST = 1 # {::Google::Cloud::Video::Transcoder::V1::SegmentSettings#individual_segments SegmentSettings.individual_segments} # must be set to `true` to use this segment reference scheme. Uses the # DASH specification # `<SegmentTemplate>` tag to determine the URLs of media files for each # segment. For example: # ```xml # <SegmentTemplate presentationTimeOffset="0" timescale="10000" # initialization="my-hd-stream-init.m4s" # media="hd-stream$Number%010d$.m4s" startNumber="0"> # ... # ``` SEGMENT_TEMPLATE_NUMBER = 2 end end # The manifest type, which corresponds to the adaptive streaming format used. module ManifestType # The manifest type is not specified. MANIFEST_TYPE_UNSPECIFIED = 0 # Create an HLS manifest. The corresponding file extension is `.m3u8`. HLS = 1 # Create an MPEG-DASH manifest. The corresponding file extension is `.mpd`. DASH = 2 end end |
#type ⇒ ::Google::Cloud::Video::Transcoder::V1::Manifest::ManifestType
Returns Required. Type of the manifest.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 421 class Manifest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `DASH` manifest configuration. # @!attribute [rw] segment_reference_scheme # @return [::Google::Cloud::Video::Transcoder::V1::Manifest::DashConfig::SegmentReferenceScheme] # The segment reference scheme for a `DASH` manifest. The default is # `SEGMENT_LIST`. class DashConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The segment reference scheme for a `DASH` manifest. module SegmentReferenceScheme # The segment reference scheme is not specified. SEGMENT_REFERENCE_SCHEME_UNSPECIFIED = 0 # Explicitly lists the URLs of media files for each segment. For example, # if # {::Google::Cloud::Video::Transcoder::V1::SegmentSettings#individual_segments SegmentSettings.individual_segments} # is `true`, then the manifest contains fields similar to the following: # ```xml # <Initialization sourceURL="my-hd-stream-init.m4s"/> # <SegmentList presentationTimeOffset="0" duration="1000" # timescale="10000"> # <SegmentURL media="hd-stream0000000000.m4s"/> # <SegmentURL media="hd-stream0000000001.m4s"/> # ... # ``` SEGMENT_LIST = 1 # {::Google::Cloud::Video::Transcoder::V1::SegmentSettings#individual_segments SegmentSettings.individual_segments} # must be set to `true` to use this segment reference scheme. Uses the # DASH specification # `<SegmentTemplate>` tag to determine the URLs of media files for each # segment. For example: # ```xml # <SegmentTemplate presentationTimeOffset="0" timescale="10000" # initialization="my-hd-stream-init.m4s" # media="hd-stream$Number%010d$.m4s" startNumber="0"> # ... # ``` SEGMENT_TEMPLATE_NUMBER = 2 end end # The manifest type, which corresponds to the adaptive streaming format used. module ManifestType # The manifest type is not specified. MANIFEST_TYPE_UNSPECIFIED = 0 # Create an HLS manifest. The corresponding file extension is `.m3u8`. HLS = 1 # Create an MPEG-DASH manifest. The corresponding file extension is `.mpd`. DASH = 2 end end |