Class: Google::Cloud::Video::Transcoder::V1::MuxStream
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::MuxStream
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
Multiplexing settings for output stream.
Defined Under Namespace
Classes: Fmp4Config
Instance Attribute Summary collapse
-
#container ⇒ ::String
The container format.
-
#elementary_streams ⇒ ::Array<::String>
List of ElementaryStream.key values multiplexed in this stream.
-
#encryption_id ⇒ ::String
Identifier of the encryption configuration to use.
-
#file_name ⇒ ::String
The name of the generated file.
-
#fmp4 ⇒ ::Google::Cloud::Video::Transcoder::V1::MuxStream::Fmp4Config
Optional.
-
#key ⇒ ::String
A unique key for this multiplexed stream.
-
#segment_settings ⇒ ::Google::Cloud::Video::Transcoder::V1::SegmentSettings
Segment settings for
ts,fmp4andvtt.
Instance Attribute Details
#container ⇒ ::String
Returns The container format. The default is mp4
Supported streaming formats:
tsfmp4- the corresponding file extension is.m4s
Supported standalone file formats:
mp4mp3oggvtt
See also: Supported input and output formats.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 379 class MuxStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `fmp4` container configuration. # @!attribute [rw] codec_tag # @return [::String] # Optional. Specify the codec tag string that will be used in the media # bitstream. When not specified, the codec appropriate value is used. # # Supported H265 codec tags: # # - `hvc1` (default) # - `hev1` class Fmp4Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#elementary_streams ⇒ ::Array<::String>
Returns List of ElementaryStream.key values multiplexed in this stream.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 379 class MuxStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `fmp4` container configuration. # @!attribute [rw] codec_tag # @return [::String] # Optional. Specify the codec tag string that will be used in the media # bitstream. When not specified, the codec appropriate value is used. # # Supported H265 codec tags: # # - `hvc1` (default) # - `hev1` class Fmp4Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#encryption_id ⇒ ::String
Returns Identifier of the encryption configuration to use. If omitted, output will be unencrypted.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 379 class MuxStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `fmp4` container configuration. # @!attribute [rw] codec_tag # @return [::String] # Optional. Specify the codec tag string that will be used in the media # bitstream. When not specified, the codec appropriate value is used. # # Supported H265 codec tags: # # - `hvc1` (default) # - `hev1` class Fmp4Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#file_name ⇒ ::String
Returns The name of the generated file. The default is MuxStream.key with the extension suffix corresponding to the MuxStream.container.
Individual segments also have an incremental 10-digit zero-padded suffix
starting from 0 before the extension, such as mux_stream0000000123.ts.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 379 class MuxStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `fmp4` container configuration. # @!attribute [rw] codec_tag # @return [::String] # Optional. Specify the codec tag string that will be used in the media # bitstream. When not specified, the codec appropriate value is used. # # Supported H265 codec tags: # # - `hvc1` (default) # - `hev1` class Fmp4Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#fmp4 ⇒ ::Google::Cloud::Video::Transcoder::V1::MuxStream::Fmp4Config
Returns Optional. fmp4 container configuration.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 379 class MuxStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `fmp4` container configuration. # @!attribute [rw] codec_tag # @return [::String] # Optional. Specify the codec tag string that will be used in the media # bitstream. When not specified, the codec appropriate value is used. # # Supported H265 codec tags: # # - `hvc1` (default) # - `hev1` class Fmp4Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#key ⇒ ::String
Returns A unique key for this multiplexed stream.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 379 class MuxStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `fmp4` container configuration. # @!attribute [rw] codec_tag # @return [::String] # Optional. Specify the codec tag string that will be used in the media # bitstream. When not specified, the codec appropriate value is used. # # Supported H265 codec tags: # # - `hvc1` (default) # - `hev1` class Fmp4Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#segment_settings ⇒ ::Google::Cloud::Video::Transcoder::V1::SegmentSettings
Returns Segment settings for ts, fmp4 and vtt.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 379 class MuxStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # `fmp4` container configuration. # @!attribute [rw] codec_tag # @return [::String] # Optional. Specify the codec tag string that will be used in the media # bitstream. When not specified, the codec appropriate value is used. # # Supported H265 codec tags: # # - `hvc1` (default) # - `hev1` class Fmp4Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |