Class: Google::Cloud::Video::Transcoder::V1::MuxStream::Fmp4Config
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::MuxStream::Fmp4Config
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
fmp4 container configuration.
Instance Attribute Summary collapse
-
#codec_tag ⇒ ::String
Optional.
Instance Attribute Details
#codec_tag ⇒ ::String
Returns Optional. Specify the codec tag string that will be used in the media bitstream. When not specified, the codec appropriate value is used.
Supported H265 codec tags:
hvc1(default)hev1.
393 394 395 396 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 393 class Fmp4Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |