Class: Google::Cloud::Video::Transcoder::V1::PreprocessingConfig::Deinterlace
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::PreprocessingConfig::Deinterlace
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
Deinterlace configuration for input video.
Defined Under Namespace
Classes: BwdifConfig, YadifConfig
Instance Attribute Summary collapse
-
#bwdif ⇒ ::Google::Cloud::Video::Transcoder::V1::PreprocessingConfig::Deinterlace::BwdifConfig
Specifies the Bob Weaver Deinterlacing Filter Configuration.
-
#yadif ⇒ ::Google::Cloud::Video::Transcoder::V1::PreprocessingConfig::Deinterlace::YadifConfig
Specifies the Yet Another Deinterlacing Filter Configuration.
Instance Attribute Details
#bwdif ⇒ ::Google::Cloud::Video::Transcoder::V1::PreprocessingConfig::Deinterlace::BwdifConfig
Returns Specifies the Bob Weaver Deinterlacing Filter Configuration.
Note: The following fields are mutually exclusive: bwdif, yadif. If a field in that set is populated, all other fields in the set will automatically be cleared.
866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 866 class Deinterlace include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Yet Another Deinterlacing Filter Configuration. # @!attribute [rw] mode # @return [::String] # Specifies the deinterlacing mode to adopt. # The default is `send_frame`. # Supported values: # # - `send_frame`: Output one frame for each frame # - `send_field`: Output one frame for each field # @!attribute [rw] disable_spatial_interlacing # @return [::Boolean] # Disable spacial interlacing. # The default is `false`. # @!attribute [rw] parity # @return [::String] # The picture field parity assumed for the input interlaced video. # The default is `auto`. # Supported values: # # - `tff`: Assume the top field is first # - `bff`: Assume the bottom field is first # - `auto`: Enable automatic detection of field parity # @!attribute [rw] deinterlace_all_frames # @return [::Boolean] # Deinterlace all frames rather than just the frames identified as # interlaced. The default is `false`. class YadifConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Bob Weaver Deinterlacing Filter Configuration. # @!attribute [rw] mode # @return [::String] # Specifies the deinterlacing mode to adopt. # The default is `send_frame`. # Supported values: # # - `send_frame`: Output one frame for each frame # - `send_field`: Output one frame for each field # @!attribute [rw] parity # @return [::String] # The picture field parity assumed for the input interlaced video. # The default is `auto`. # Supported values: # # - `tff`: Assume the top field is first # - `bff`: Assume the bottom field is first # - `auto`: Enable automatic detection of field parity # @!attribute [rw] deinterlace_all_frames # @return [::Boolean] # Deinterlace all frames rather than just the frames identified as # interlaced. The default is `false`. class BwdifConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#yadif ⇒ ::Google::Cloud::Video::Transcoder::V1::PreprocessingConfig::Deinterlace::YadifConfig
Returns Specifies the Yet Another Deinterlacing Filter Configuration.
Note: The following fields are mutually exclusive: yadif, bwdif. If a field in that set is populated, all other fields in the set will automatically be cleared.
866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 866 class Deinterlace include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Yet Another Deinterlacing Filter Configuration. # @!attribute [rw] mode # @return [::String] # Specifies the deinterlacing mode to adopt. # The default is `send_frame`. # Supported values: # # - `send_frame`: Output one frame for each frame # - `send_field`: Output one frame for each field # @!attribute [rw] disable_spatial_interlacing # @return [::Boolean] # Disable spacial interlacing. # The default is `false`. # @!attribute [rw] parity # @return [::String] # The picture field parity assumed for the input interlaced video. # The default is `auto`. # Supported values: # # - `tff`: Assume the top field is first # - `bff`: Assume the bottom field is first # - `auto`: Enable automatic detection of field parity # @!attribute [rw] deinterlace_all_frames # @return [::Boolean] # Deinterlace all frames rather than just the frames identified as # interlaced. The default is `false`. class YadifConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Bob Weaver Deinterlacing Filter Configuration. # @!attribute [rw] mode # @return [::String] # Specifies the deinterlacing mode to adopt. # The default is `send_frame`. # Supported values: # # - `send_frame`: Output one frame for each frame # - `send_field`: Output one frame for each field # @!attribute [rw] parity # @return [::String] # The picture field parity assumed for the input interlaced video. # The default is `auto`. # Supported values: # # - `tff`: Assume the top field is first # - `bff`: Assume the bottom field is first # - `auto`: Enable automatic detection of field parity # @!attribute [rw] deinterlace_all_frames # @return [::Boolean] # Deinterlace all frames rather than just the frames identified as # interlaced. The default is `false`. class BwdifConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |