Class: Google::Cloud::Video::Transcoder::V1::TextStream
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::TextStream
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
Encoding of a text stream. For example, closed captions or subtitles.
Defined Under Namespace
Classes: TextMapping
Instance Attribute Summary collapse
-
#codec ⇒ ::String
The codec for this text stream.
-
#display_name ⇒ ::String
The name for this particular text stream that will be added to the HLS/DASH manifest.
-
#language_code ⇒ ::String
The BCP-47 language code, such as
en-USorsr-Latn. -
#mapping ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1::TextStream::TextMapping>
The mapping for the JobConfig.edit_list atoms with text EditAtom.inputs.
Instance Attribute Details
#codec ⇒ ::String
Returns The codec for this text stream. The default is webvtt.
Supported text codecs:
srtttmlcea608cea708webvtt.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1605 class TextStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with text # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references atom with text inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. class TextMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns The name for this particular text stream that will be added to the HLS/DASH manifest. Not supported in MP4 files.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1605 class TextStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with text # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references atom with text inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. class TextMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#language_code ⇒ ::String
Returns The BCP-47 language code, such as en-US or sr-Latn. For more
information, see
https://www.unicode.org/reports/tr35/#Unicode_locale_identifier. Not
supported in MP4 files.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1605 class TextStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with text # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references atom with text inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. class TextMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#mapping ⇒ ::Array<::Google::Cloud::Video::Transcoder::V1::TextStream::TextMapping>
Returns The mapping for the JobConfig.edit_list atoms with text EditAtom.inputs.
1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 1605 class TextStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mapping for the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list} # atoms with text # {::Google::Cloud::Video::Transcoder::V1::EditAtom#inputs EditAtom.inputs}. # @!attribute [rw] atom_key # @return [::String] # Required. The # {::Google::Cloud::Video::Transcoder::V1::EditAtom#key EditAtom.key} that # references atom with text inputs in the # {::Google::Cloud::Video::Transcoder::V1::JobConfig#edit_list JobConfig.edit_list}. # @!attribute [rw] input_key # @return [::String] # Required. The {::Google::Cloud::Video::Transcoder::V1::Input#key Input.key} # that identifies the input file. # @!attribute [rw] input_track # @return [::Integer] # Required. The zero-based index of the track in the input file. class TextMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |