Class: Google::Cloud::Video::Transcoder::V1::TrackDefinition
- Inherits:
-
Object
- Object
- Google::Cloud::Video::Transcoder::V1::TrackDefinition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
Track definition for the input asset.
Instance Attribute Summary collapse
-
#detect_languages ⇒ ::Boolean
Optional.
-
#detected_languages ⇒ ::Array<::String>
readonly
Output only.
-
#input_track ⇒ ::Integer
The input track.
-
#languages ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#detect_languages ⇒ ::Boolean
Returns Optional. Whether to automatically detect the languages present in the track. If true, the system will attempt to identify all the languages present in the track and populate the languages field.
951 952 953 954 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 951 class TrackDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#detected_languages ⇒ ::Array<::String> (readonly)
Returns Output only. A list of languages detected in the input asset, represented by a BCP 47 language code, such as "en-US" or "sr-Latn". For more information, see https://www.unicode.org/reports/tr35/#Unicode_locale_identifier. This field is only populated if the detect_languages field is set to true.
951 952 953 954 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 951 class TrackDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#input_track ⇒ ::Integer
Returns The input track.
951 952 953 954 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 951 class TrackDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#languages ⇒ ::Array<::String>
Returns Optional. A list of languages spoken in the input asset, represented by a BCP 47 language code, such as "en-US" or "sr-Latn". For more information, see https://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
951 952 953 954 |
# File 'proto_docs/google/cloud/video/transcoder/v1/resources.rb', line 951 class TrackDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |