Module: Google::Cloud::Video::Transcoder::V1::VideoStream::FrameRateConversionStrategy
- Defined in:
- proto_docs/google/cloud/video/transcoder/v1/resources.rb
Overview
The conversion strategy for desired frame rate.
Constant Summary collapse
- FRAME_RATE_CONVERSION_STRATEGY_UNSPECIFIED =
Unspecified frame rate conversion strategy.
0- DOWNSAMPLE =
Selectively retain frames to reduce the output frame rate. Every n th frame is kept, where
n = ceil(input frame rate / target frame rate). When n = 1 (that is, the target frame rate is greater than the input frame rate), the output frame rate matches the input frame rate. When n > 1, frames are dropped and the output frame rate is equal to(input frame rate / n). For more information, see Calculate frame rate. 1- DROP_DUPLICATE =
Drop or duplicate frames to match the specified frame rate.
2